@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Change audio file anchors to audio elements
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use v5.20.0;
 
@@ -21,9 +21,11 @@ has file_type => (
 sub audio_tag {
     my ($self, $page) = @_;
     if ($page->has_dom) {
-        $page->dom->find('a[href$=.'. $self->file_type .']' )->each(sub {
+        $page->dom->find('a[href$=.'. $self->file_type .']')->each(sub {
             my ($el) = @_;
-            $el->replace(sprintf '<audio controls><source type="audio/%s" src="%s"></audio>', $self->file_type, $el->attr('href'));
+            my $replacement = sprintf '<audio controls><source type="audio/%s" src="%s"></audio>',
+                $self->file_type, $el->attr('href');
+            $el->replace($replacement);
         });
     }
     return $page;
@@ -54,7 +56,7 @@ Statocles::Plugin::AudioTag - Change audio file anchors to audio elements
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -99,6 +101,8 @@ L<Statocles>
 
 L<Statocles::Plugin>
 
+L<https://ology.github.io/2020/12/06/making-a-statocles-plugin/>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
